@@ -112,6 +112,8 @@ gdal <- function(warn=NA, drivers=FALSE, lib="gdal") {
 setMethod("describe", signature(x="character"),
 	function(x, sds=FALSE, meta=FALSE, parse=FALSE, options="", print=FALSE, open_opt="") {
 
+		#x <- .fullFilename(x[1], FALSE)
+		x <- x[1]
 		if (meta) {
 			if (sds) {
 				return(.meta_sds(x, parse))
