@@ -95,7 +95,7 @@ setMethod("relate", signature(x="SpatVector", y="SpatVector"),
 				m[do.call(cbind, out) + 1] <- TRUE
 			}
 			m
-			
+
 #			out <- x@ptr$relate_between(y@ptr, relation, TRUE, TRUE)
 #			messages(x, "relate")
 #			out[out == 2] <- NA
@@ -148,7 +148,7 @@ setMethod("relate", signature(x="SpatRaster", y="SpatVector"),
 setMethod("relate", signature(x="SpatExtent", y="SpatRaster"),
 	function(x, y, relation, ...) {
 		x <- as.polygons(x)
-		y <- as.polygons(y, ext=TRUE)		
+		y <- as.polygons(y, ext=TRUE)
 		relate(x, y, relation, ...)
 	}
 )
@@ -204,7 +204,7 @@ setMethod("relate", signature(x="SpatVector", y="missing"),
 			#	m
 			#}
 		}
-			
+
 		#out <- x@ptr$relate_within(relation, symmetrical)
 		#out[out == 2] <- NA
 		#if (symmetrical) {
@@ -230,7 +230,7 @@ setMethod("adjacent", signature(x="SpatRaster"),
 		if (inherits(directions, "matrix")) {
 			v <- x@ptr$adjacentMat(cells, as.logical(directions), dim(directions), include)
 		} else {
-			if (pairs) include <- FALSE
+			#if (pairs) include <- FALSE
 			v <- x@ptr$adjacent(cells,  as.character(directions)[1], include)
 		}
 		messages(x, "adjacent")
@@ -269,6 +269,12 @@ setMethod("adjacent", signature(x="SpatVector"),
 
 setMethod("nearby", signature(x="SpatVector"),
 	function(x, y=NULL, distance=0, k=1, centroids=TRUE, symmetrical=TRUE) {
+		
+		k <- round(k)
+		if (distance <= 0 && k < 1) {
+			error("nearby", "either distance or k must be a positive number")
+		}
+
 		if ((geomtype(x) == "polygons") && centroids) {
 			x <- centroids(x)
 		}
@@ -292,7 +298,7 @@ setMethod("nearby", signature(x="SpatVector"),
 			} else {
 				k <- max(1, min(round(k), (nrow(x)-1)))
 			}
-			if (k > 1) {
+#			if (k > 1) {
 				if (hasy) {
 					d <- distance(x, y)
 				} else {
@@ -302,10 +308,10 @@ setMethod("nearby", signature(x="SpatVector"),
 				d <- t(apply(d, 1, function(i) order(i)[1:k]))
 				if (k==1) d <- t(d)
 				d <- cbind(1:length(x), d)
-			} else {
-				d <- nearest(x)
-				d <- values(d)[, c("from_id", "to_id")]
-			}
+#			} else {
+#				d <- nearest(x)
+#				d <- values(d)[, c("from_id", "to_id")]
+#			}
 			colnames(d) <- c("id", paste0("k", 1:k))
 			d
 		}
