@@ -140,9 +140,8 @@ bool read_aux_json(std::string filename, std::vector<int_64> &time, std::string
 
 
 
-SpatCategories GetRAT(GDALRasterAttributeTable *pRAT) {
+bool GetRAT(GDALRasterAttributeTable *pRAT, SpatCategories &cats, const std::string &driver) {
 
-	SpatCategories out;
 /*
 	const char *GFU_type_string[] = {"GFT_Integer", "GFT_Real","GFT_String"};
 	const char *GFU_usage_string[] = {"GFU_Generic", "GFU_PixelCount", "GFU_Name", "GFU_Min",
@@ -155,23 +154,21 @@ SpatCategories GetRAT(GDALRasterAttributeTable *pRAT) {
 	size_t nc = (int) pRAT->GetColumnCount();
 	size_t nr = (int) pRAT->GetRowCount();
 
-	std::vector<std::string> ss = {"histogram", "count", "red", "green", "blue", "opacity", "r", "g", "b", "alpha"};
+	std::vector<std::string> ss = {"histogram", "count", "red", "green", "blue", "alpha", "opacity", "r", "g", "b", "a"};
 
-	//std::vector<std::string> ratnms;
+	std::vector<std::string> ratnms;
 	std::vector<int> id, id2;
 
 	bool hasvalue=false;
-	//std::string valuename = "";
 	for (size_t i=0; i<nc; i++) {
 		std::string name = pRAT->GetNameOfCol(i);
+		ratnms.push_back(name);
 		lowercase(name);
-		//ratnms.push_back(name);
-		if (!hasvalue && ((name == "value") || (name == "id"))) {
+		if (!hasvalue && ((name == "value") || (name == "id") || (name == "ids"))) {
 			id.insert(id.begin(), i);
 			hasvalue = true;
-			//valuename = name;
 		} else {
-			int k = where_in_vector(name, ss, true);
+			int k = where_in_vector(name, ss, false);
 			if (k >= 0) {
 				id2.push_back(i);
 			} else {
@@ -179,22 +176,34 @@ SpatCategories GetRAT(GDALRasterAttributeTable *pRAT) {
 			}
 		}
 	}
-	if (id.size() < 1) {
+	bool good_rat = true;
+	size_t sid = id.size();
+//	Rcpp::Rcout << hasvalue << " " << sid << std::endl;
+	if ((hasvalue && sid == 1) || ((!hasvalue) && sid == 0)) {
 // #790 avoid having just "count" or "histogram" 
-		return(out);
+		good_rat = false;
 	}
 	id.insert(id.end(), id2.begin(), id2.end());
 
+	if (driver == "AIG") {
+		std::vector<std::string> compnms = {"ID", "VALUE", "COUNT"};
+		if ((id.size() == 3) && (ratnms == compnms)) {
+			cats.index = -1;
+			return false;
+		}
+	}
+
 	if (!hasvalue) {
 		std::vector<long> vid(nr);
 		std::iota(vid.begin(), vid.end(), 0);
-		out.d.add_column(vid, "value");
+		cats.d.add_column(vid, "value");
 	}
 
+	int first_string = -1;
+
 	for (size_t k=0; k<id.size(); k++) {
 		size_t i = id[k];
 		std::string name = pRAT->GetNameOfCol(i);
-
 		GDALRATFieldType nc_type = pRAT->GetTypeOfCol(i);
 //		GFT_type.push_back(GFU_type_string[nc_types[i]]);
 //		GDALRATFieldUsage nc_usage = pRAT->GetUsageOfCol(i);
@@ -205,23 +214,27 @@ SpatCategories GetRAT(GDALRasterAttributeTable *pRAT) {
 			for (size_t j=0; j<nr; j++) {
 				d[j] = (int) pRAT->GetValueAsInt(j, i);
 			}
-			out.d.add_column(d, name);
+			cats.d.add_column(d, name);
 		} else if (nc_type == GFT_Real) {
 			std::vector<double> d(nr);
 			for (size_t j=0; j<nr; j++) {
 				d[j] = (double) pRAT->GetValueAsDouble(j, i);
 			}
-			out.d.add_column(d, name);
+			cats.d.add_column(d, name);
 		} else if (nc_type == GFT_String) {
 			std::vector<std::string> d(nr);
 			for (size_t j=0; j<nr; j++) {
 				d[j] = (std::string) pRAT->GetValueAsString(j, i);
 			}
-			out.d.add_column(d, name);
+			if (first_string < 0) first_string = cats.d.ncol();
+			cats.d.add_column(d, name);
 		}
+	}	
+	if (cats.d.nrow() == 0) {
+		return false;
 	}
-	out.index = out.d.ncol() > 1 ? 1 : 0;
-	return(out);
+	cats.index = good_rat ? (first_string >= 0 ? first_string :(cats.d.ncol() > 1 ? 1 : 0)) : -1;
+	return true;
 }
 
 
@@ -338,72 +351,64 @@ bool setIntCol(SpatDataFrame &d, SpatDataFrame &out, int k, std::string name) {
 
 bool colsFromRat(SpatDataFrame &d, SpatDataFrame &out) {
 
+	if ((d.nrow() == 0) || (d.ncol() == 0)) {
+		return false;
+	}
 
 	std::vector<std::string> ss = d.get_names();
 	for (size_t i=0; i<ss.size(); i++) {
 		lowercase(ss[i]);
 	}
-
-	int k = where_in_vector("value", ss, true);
-	if (k >= 0) {
-		size_t j = d.iplace[k];
+//	int k = where_in_vector("value", ss, true);
+//	if (k >= 0) {
+	int k = 0;  
+	size_t j = d.iplace[k];
 		
-		if (d.itype[k] == 1) {
-			out.add_column(d.iv[j], "value");
-		} else if (d.itype[k] == 0) {
-			std::vector<long> x;
-			x.reserve(d.nrow());
-			for (size_t i=0; i<d.nrow(); i++) {
-				x.push_back(d.dv[j][i]);
-			}
-			out.add_column(x, "value");
+	if (d.itype[k] == 1) {
+		out.add_column(d.iv[j], "value");
+	} else if (d.itype[k] == 0) {
+		std::vector<long> x;
+		x.reserve(d.nrow());
+		for (size_t i=0; i<d.nrow(); i++) {
+			x.push_back(d.dv[j][i]);
 		}
+		out.add_column(x, "value");
 	} else {
 		return false;
 	}
 
-
-//	int k = where_in_vector("colors", ss, true);
-//	if (k >= 0) {
-		//col2rgb(d, out, k);
-//	} else {
-		std::vector<std::string> cols1 = {"red", "green", "blue"};
-		std::vector<std::string> cols2 = {"r", "g", "b"};
-		for (size_t i=0; i<3; i++) {
-			int k = where_in_vector(cols1[i], ss, true);
-			if (k >= 0) {
+	std::vector<std::string> cols1 = {"red", "green", "blue"};
+	std::vector<std::string> cols2 = {"r", "g", "b"};
+	for (size_t i=0; i<3; i++) {
+		int k = where_in_vector(cols1[i], ss, true);
+		if (k >= 0) {
+			if (!setIntCol(d, out, k, cols1[i])) return false;
+		} else {
+				int k = where_in_vector(cols2[i], ss, true);
+		if (k >= 0) {
 				if (!setIntCol(d, out, k, cols1[i])) return false;
 			} else {
-				int k = where_in_vector(cols2[i], ss, true);
-				if (k >= 0) {
-					if (!setIntCol(d, out, k, cols1[i])) return false;
-				} else {
-					return false;
-				}
+				return false;
 			}
 		}
-
-		bool have_alpha = false;
-		k = where_in_vector("alpha", ss, true);
+	}
+	k = where_in_vector("alpha", ss, true);
+	if (k >= 0) {
+		setIntCol(d, out, k, "alpha");
+	} else {
+		int k = where_in_vector("transparency", ss, true);
 		if (k >= 0) {
-			if (setIntCol(d, out, k, "alpha")) have_alpha = true;
-		}
-
-		if (!have_alpha) {
-			int k = where_in_vector("transparency", ss, true);
+			setIntCol(d, out, k, "alpha");
+		} else {
+			int k = where_in_vector("opacity", ss, true);
 			if (k >= 0) {
-				if (setIntCol(d, out, k, "alpha")) have_alpha = true;
+				setIntCol(d, out, k, "alpha");
+			} else {
+				std::vector<long> a(out.nrow(), 255);
+				out.add_column(a, "alpha");
 			}
 		}
-
-		if (!have_alpha) {
-			std::vector<long> a(out.nrow(), 255);
-			out.add_column(a, "alpha");
-		}
-//	}
-	
-	d = out;
-
+	}
 	return true;
 }
 
@@ -977,28 +982,15 @@ bool SpatRaster::constructFromFile(std::string fname, std::vector<int> subds, st
 			s.hasCategories[i] = true;
 		}
 
-		bool have_rat = false;
 		SpatCategories crat;
-
+		bool found_rat = false;
+		
 		if (!s.hasCategories[i]) {
 			GDALRasterAttributeTable *rat = poBand->GetDefaultRAT();
-			if( rat != NULL ) {
-				crat = GetRAT(rat);
-				if (crat.d.nrow() > 0) {
-					if (gdrv == "AIG") {
-						std::vector<std::string> catnms = crat.d.get_names();
-						std::vector<std::string> compnms = {"ID", "VALUE", "COUNT"};
-						if ((catnms.size() > 3) || (catnms != compnms)) {
-							s.cats[i] = crat;
-							s.hasCategories[i] = true;
-							have_rat = true;
-						}
-					} else {
-						s.cats[i] = crat;
-						s.hasCategories[i] = true;
-						have_rat = true;
-					}
-				}
+			if (rat != NULL) {
+				found_rat = GetRAT(rat, crat, gdrv);
+				s.cats[i] = crat;
+				s.hasCategories[i] = true;
 			}
 		}
 		//	} else {
@@ -1009,11 +1001,11 @@ bool SpatRaster::constructFromFile(std::string fname, std::vector<int> subds, st
 			if (GetVAT(fname, crat)) {
 				s.cats[i] = crat;
 				s.hasCategories[i] = true;
-				have_rat = true;
+				found_rat = true;
 			}
 		}
 
-		if ((!s.hasColors[i]) && (have_rat)) {
+		if ((!s.hasColors[i]) && (found_rat)) {
 			SpatDataFrame ratcols;
 			if (colsFromRat(crat.d, ratcols)) {
 				s.hasColors[i] = true;
@@ -1023,7 +1015,7 @@ bool SpatRaster::constructFromFile(std::string fname, std::vector<int> subds, st
 
 		std::string nm = "";
 		if (s.hasCategories[i]) {
-			if (s.cats[i].index < s.cats[i].d.ncol()) {
+			if ((s.cats[i].index >= 0) && (s.cats[i].index < (int)s.cats[i].d.ncol())) {
 				std::vector<std::string> nms = s.cats[i].d.get_names();
 				nm = nms[s.cats[i].index];
 			}
@@ -1650,8 +1642,8 @@ bool SpatRaster::constructFromSDS(std::string filename, std::vector<std::string>
 				sd.push_back(info[0][i]);
 				varname.push_back(info[1][i]);
 				srcname.push_back(info[2][i]);
-				rows.push_back(stoi(info[3][i]));
-				cols.push_back(stoi(info[4][i]));
+				rows.push_back(std::stol(info[3][i]));
+				cols.push_back(std::stol(info[4][i]));
 			}
 		}
 		if (sd.empty()) { // all were removed
@@ -1665,8 +1657,8 @@ bool SpatRaster::constructFromSDS(std::string filename, std::vector<std::string>
 					sd.push_back(info[0][i]);
 					varname.push_back(info[1][i]);
 					srcname.push_back(info[2][i]);
-					rows.push_back(stoi(info[3][i]));
-					cols.push_back(stoi(info[4][i]));
+					rows.push_back(std::stol(info[3][i]));
+					cols.push_back(std::stol(info[4][i]));
 				}
 			}
 		}
@@ -1748,7 +1740,7 @@ std::vector<int_64> ncdf_str2int64v(std::string s, std::string delim) {
 
 bool get_long(std::string input, long &output) {
     try  {
-		output = std::stoi(input);
+		output = std::stol(input);
 		return true;
     } catch (std::invalid_argument &e)  {
 		return false;
